@@ -83,7 +83,7 @@ couchdb_document_get (CouchDB *couchdb,
 	g_return_val_if_fail (docid != NULL, NULL);
 
 	url = g_strdup_printf ("http://%s/%s/%s", couchdb->hostname, dbname, docid);
-	parser = send_message_and_parse (couchdb, SOUP_METHOD_GET, url, error);
+	parser = send_message_and_parse (couchdb, SOUP_METHOD_GET, url, NULL, error);
 	if (parser) {
 		document = g_object_new (COUCHDB_TYPE_DOCUMENT, NULL);
 		document->couchdb = couchdb;
@@ -98,6 +98,48 @@ couchdb_document_get (CouchDB *couchdb,
 	return document;
 }
 
+gboolean
+couchdb_document_put (CouchDBDocument *document, GError **error)
+{
+	char *url, *body;
+	const char *id;
+	JsonParser *parser;
+	gboolean result = FALSE;
+
+	g_return_val_if_fail (COUCHDB_IS_DOCUMENT (document), FALSE);
+
+	if (!document->dbname) {
+		g_warning ("Document does not have a database associated to it");
+		return FALSE;
+	}
+
+	id = couchdb_document_get_string_field (document, "_id");
+	body = couchdb_document_to_string (document);
+	if (id) {
+		url = g_strdup_printf ("http://%s/%s/%s", document->couchdb->hostname, document->dbname, id);
+		parser = send_message_and_parse (document->couchdb, SOUP_METHOD_PUT, url, body, error);
+	} else {
+		url = g_strdup_printf ("http://%s/%s/", document->couchdb->hostname, document->dbname);
+		parser = send_message_and_parse (document->couchdb, SOUP_METHOD_POST, url, body, error);
+	}
+
+	if (parser) {
+		JsonObject *object;
+
+		object = json_node_get_object (json_parser_get_root (parser));
+		couchdb_document_set_string_field (document, "_id", json_object_get_string_member (object, "id"));
+		couchdb_document_set_string_field (document, "_rev", json_object_get_string_member (object, "rev"));
+
+		g_object_unref (G_OBJECT (parser));
+	}
+
+	/* free memory */
+	g_free (url);
+	g_free (body);
+
+	return result;
+}
+
 const char *
 couchdb_document_get_id (CouchDBDocument *document)
 {
@@ -145,8 +187,8 @@ couchdb_document_is_contact (CouchDBDocument *document)
 	g_return_val_if_fail (COUCHDB_IS_DOCUMENT (document), FALSE);
 
 	return !g_ascii_strcasecmp (json_object_get_string_member (json_node_get_object (document->root_node),
-								   "u1_record_type"),
-				    "http://api.ubuntuone.com/schema/contact/0.1");
+								   "record_type"),
+				    "http://example.com/contact-record");
 }
 
 gboolean
